@@ -35,7 +35,7 @@ typedef struct {
 static inline sp_regexp* sp_regexp_compile(zend_string *zstr) {
   sp_pcre *re = sp_pcre_compile(ZSTR_VAL(zstr));
   if (!re) { return NULL; }
-  sp_regexp *ret = pecalloc(sizeof(sp_regexp), 1, 1);
+  sp_regexp *ret = pecalloc(1, sizeof(sp_regexp), 1);
   ret->re = re;
   ret->pattern = zstr;
   return ret;
